@@ -66,7 +66,7 @@ int mount_cdrom() {
 		return(EXIT_SUCCESS);
 
 	/* unable to mount the cdrom device */
-	debconf_subst(debconf,"cdrom-checker/mntfailed", "CDROM", cdrom_device);
+	debconf_subst(debconf, "cdrom-checker/mntfailed", "CDROM", cdrom_device);
 	debconf_input(debconf, "high", "cdrom-checker/mntfailed");
 	debconf_go(debconf);
 	return(EXIT_FAILURE);
@@ -155,12 +155,9 @@ int check_cdrom() {
 }
 
 int main(int argc, char **argv) {
-	system("touch /tmp/test");
-	system("logger init");
         di_system_init(basename(argv[0]));
 	/* initialize the debconf frontend */
 	debconf = debconfclient_new();
-	system("logger after");
 
 	/* ask if we should proceed with the checking */
 	debconf_set(debconf, "cdrom-checker/start", "false");
@@ -176,7 +173,6 @@ int main(int argc, char **argv) {
 		}
 		return(EXIT_SUCCESS);
 	}
-	system("logger after-quest");
 
 	detect_cdrom();
 
@@ -206,7 +202,7 @@ int main(int argc, char **argv) {
 		debconf_set(debconf, "cdrom-checker/nextcd", "false");
 		debconf_input(debconf, "high", "cdrom-checker/nextcd");
 		debconf_go(debconf);
-		debconf_get(debconf,"cdrom-checker/nextcd");
+		debconf_get(debconf, "cdrom-checker/nextcd");
 		if(!strstr(debconf->value, "true"))
 			break;
 	}
